@@ -20,8 +20,12 @@ module Console
 			def self.new(stream, env: ENV, **options)
 				stream ||= $stderr
 				
-				if stream.tty? || mail?(env)
+				if stream.tty?
 					output = Terminal.new(stream, **options)
+				elsif self.mail?(env)
+					output = Text.new(stream, **options)
+				elsif self.github_actions?(env)
+					output = XTerm.new(stream, **options)
 				else
 					output = Serialized.new(stream, **options)
 				end
@@ -34,10 +38,13 @@ module Console
 			# Detect if we're running in a cron job or mail context where human-readable output is preferred.
 			# Cron jobs often have MAILTO set and lack TERM, or have minimal TERM values.
 			def self.mail?(env = ENV)
-				# Check for common cron environment indicators
-				return true if env.key?("MAILTO") && !env["MAILTO"].empty?
-				
-				false
+				env.key?("MAILTO") && !env["MAILTO"].empty?
+			end
+			
+			# Detect if we're running in GitHub Actions, where human-readable output is preferred.
+			# GitHub Actions sets the GITHUB_ACTIONS environment variable to "true".
+			def self.github_actions?(env = ENV)
+				env["GITHUB_ACTIONS"] == "true"
 			end
 		end
 	end
